@@ -1,7 +1,7 @@
 """
 Collection of notebook utilities
 """
-from .catalog import get_catalog, retrieve_query
+from .catalog import get_tap_service, get_catalog, retrieve_query
 from .forwarder import Forwarder
 from .utils import format_bytes, get_hostname, show_with_bokeh_server
 
@@ -9,6 +9,7 @@ __all__ = [
     Forwarder,
     format_bytes,
     get_catalog,
+    get_tap_service,
     retrieve_query,
     get_hostname,
     show_with_bokeh_server,
